@@ -350,7 +350,7 @@ CreateCompositionFields(const char        *from,
 
   if (from) {
     nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(from),
-                                    nsDependentCString(charset),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
                                     outString);
     cFields->SetFrom(outString);
   }
@@ -362,28 +362,28 @@ CreateCompositionFields(const char        *from,
 
   if (reply_to) {
     nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(reply_to),
-                                    nsDependentCString(charset),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
                                     outString);
     cFields->SetReplyTo(outString);
   }
 
   if (to) {
     nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(to),
-                                    nsDependentCString(charset),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
                                     outString);
     cFields->SetTo(outString);
   }
 
   if (cc) {
     nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(cc),
-                                    nsDependentCString(charset),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
                                     outString);
     cFields->SetCc(outString);
   }
 
   if (bcc) {
     nsMsgI18NConvertRawBytesToUTF16(nsDependentCString(bcc),
-                                    nsDependentCString(charset),
+                                    charset ? nsDependentCString(charset) : EmptyCString(),
                                     outString);
     cFields->SetBcc(outString);
   }
@@ -1687,8 +1687,10 @@ mime_parse_stream_complete(nsMIMESession *stream)
         // overwritten when saving the template again.
         // Note that always setting the draft ID here would cause drafts to be
         // overwritten when edited "as new", which is undesired.
-        if (msgComposeType == nsIMsgCompType::EditTemplate)
+        if (msgComposeType == nsIMsgCompType::EditTemplate) {
           fields->SetDraftId(mdd->url_name);
+          fields->SetTemplateId(mdd->url_name);  // Remember original template ID.
+        }
 
         if (convertToPlainText)
           fields->ConvertBodyToPlainText();
