@@ -89,7 +89,7 @@ nsContextMenu.prototype = {
         let imageCache = Cc["@mozilla.org/image/tools;1"]
                            .getService(Ci.imgITools)
                            .getImgCacheForDocument(doc);
-        let props = imageCache.findEntryProperties(popupNode.currentURI);
+        let props = imageCache.findEntryProperties(popupNode.currentURI, doc);
         if (props) {
           let nsISupportsCString = Ci.nsISupportsCString;
           contentType = props.get("type", nsISupportsCString).data;
@@ -992,8 +992,11 @@ nsContextMenu.prototype = {
   },
 
   setDesktopBackground: function() {
+    let url = (new URL(this.target.ownerDocument.location.href)).pathname;
+    let imageName = url.substr(url.lastIndexOf("/") + 1);
     openDialog("chrome://communicator/content/setDesktopBackground.xul",
-               "_blank", "chrome,modal,titlebar,centerscreen", this.target);
+               "_blank", "chrome,modal,titlebar,centerscreen", this.target,
+               imageName);
   },
 
   // Save URL of clicked-on frame.
