@@ -314,6 +314,9 @@ pref("browser.zoom.siteSpecific", true);
 // once they come to the foreground (i.e. get activated).
 pref("browser.zoom.updateBackgroundTabs", true);
 
+// Whether to show the zoom status and controls in status panel
+pref("browser.zoom.showZoomStatusPanel", false);
+
 // Zoom levels for View > Zoom and Ctrl +/- keyboard shortcuts
 pref("toolkit.zoomManager.zoomValues", "0.2,0.3,0.5,0.67,0.8,0.9,1,1.1,1.2,1.33,1.5,1.7,2,2.4,3,4,5,6,7,8");
 
