@@ -393,7 +393,7 @@ SuiteGlue.prototype = {
 
   _migrateUI: function()
   {
-    const UI_VERSION = 5;
+    const UI_VERSION = 6;
 
     // If the pref is not set this is a new or pre SeaMonkey 2.49 profile.
     // We can't tell so we just run migration with version 0.
@@ -467,7 +467,7 @@ SuiteGlue.prototype = {
       } catch (ex) {}
     }
 
-    // Pretend currentUIVersion 3 never happend (used in 2.57 for a time and became 5).
+    // Pretend currentUIVersion 3 never happend (used in 2.57 for a time and became 6).
 
     // Remove obsolete download preferences set by user.
     if (currentUIVersion < 4) {
@@ -496,14 +496,25 @@ SuiteGlue.prototype = {
       } catch (ex) {}
     }
 
-    // The XUL directory viewer is no longer provided.
-    if (currentUIVersion < 5) {
+    if (currentUIVersion < 6) {
+      // Delete obsolete ssl and strict transport security permissions.
+      let perms = Services.perms.enumerator;
+      while (perms.hasMoreElements()) {
+        let perm = perms.getNext();
+        if (perm.type == "falsestart-rc4" ||
+            perm.type == "falsestart-rsa" ||
+            perm.type == "sts/use" ||
+            perm.type == "sts/subd") {
+          Services.perms.removePermission(perm);
+        }
+      }
+
+      // The XUL directory viewer is no longer provided.
       try {
         if (Services.prefs.getIntPref("network.dir.format") == 3) {
           Services.prefs.setIntPref("network.dir.format", 2);
         }
       } catch (ex) {}
-
     }
 
     // Update the migration version.
@@ -1238,12 +1249,17 @@ SuiteGlue.prototype = {
   // public nsISuiteGlue members
   // ------------------------------
 
-  showDownloadManager: function(aDownload)
+  showDownloadManager: function(newDownload)
   {
     if (!gDownloadManager) {
+      // Use an empty arguments string or the download manager window
+      // will miss the toolbar and other features.
+      var argString = Cc["@mozilla.org/supports-string;1"]
+                        .createInstance(Ci.nsISupportsString);
+      argString.data = "";
       gDownloadManager = Services.ww.openWindow(null, DOWNLOAD_MANAGER_URL,
                                                 null, "all,dialog=no",
-                                                { wrappedJSObject: aDownload });
+                                                argString);
       gDownloadManager.addEventListener("load", function() {
         gDownloadManager.addEventListener("unload", function() {
           gDownloadManager = null;
@@ -1252,7 +1268,7 @@ SuiteGlue.prototype = {
         ChromeUtils.import("resource:///modules/DownloadsTaskbar.jsm", {})
                    .DownloadsTaskbar.attachIndicator(gDownloadManager);
       });
-    } else if (!aDownload ||
+    } else if (!newDownload ||
                Services.prefs.getBoolPref(PREF_FOCUS_WHEN_STARTING)) {
         gDownloadManager.focus();
     } else {
