@@ -68,89 +68,79 @@ StaticRefPtr<ExtensionProtocolHandler> ExtensionProtocolHandler::sSingleton;
  * stream or file descriptor from the parent for a remote moz-extension load
  * from the child.
  */
-class ExtensionStreamGetter : public RefCounted<ExtensionStreamGetter>
-{
-  public:
-    // To use when getting a remote input stream for a resource
-    // in an unpacked extension.
-    ExtensionStreamGetter(nsIURI* aURI, nsILoadInfo* aLoadInfo)
-      : mURI(aURI)
-      , mLoadInfo(aLoadInfo)
-      , mIsJarChannel(false)
-    {
-      MOZ_ASSERT(aURI);
-      MOZ_ASSERT(aLoadInfo);
+class ExtensionStreamGetter : public RefCounted<ExtensionStreamGetter> {
+ public:
+  // To use when getting a remote input stream for a resource
+  // in an unpacked extension.
+  ExtensionStreamGetter(nsIURI* aURI, nsILoadInfo* aLoadInfo)
+      : mURI(aURI), mLoadInfo(aLoadInfo), mIsJarChannel(false) {
+    MOZ_ASSERT(aURI);
+    MOZ_ASSERT(aLoadInfo);
 
-      SetupEventTarget();
+    SetupEventTarget();
+  }
+
+  // To use when getting an FD for a packed extension JAR file
+  // in order to load a resource.
+  ExtensionStreamGetter(nsIURI* aURI, nsILoadInfo* aLoadInfo,
+                        already_AddRefed<nsIJARChannel>&& aJarChannel,
+                        nsIFile* aJarFile)
+      : mURI(aURI),
+        mLoadInfo(aLoadInfo),
+        mJarChannel(Move(aJarChannel)),
+        mJarFile(aJarFile),
+        mIsJarChannel(true) {
+    MOZ_ASSERT(aURI);
+    MOZ_ASSERT(aLoadInfo);
+    MOZ_ASSERT(mJarChannel);
+    MOZ_ASSERT(aJarFile);
+
+    SetupEventTarget();
+  }
+
+  ~ExtensionStreamGetter() {}
+
+  void SetupEventTarget() {
+    mMainThreadEventTarget = nsContentUtils::GetEventTargetByLoadInfo(
+        mLoadInfo, TaskCategory::Other);
+    if (!mMainThreadEventTarget) {
+      mMainThreadEventTarget = GetMainThreadSerialEventTarget();
     }
+  }
 
-    // To use when getting an FD for a packed extension JAR file
-    // in order to load a resource.
-    ExtensionStreamGetter(nsIURI* aURI, nsILoadInfo* aLoadInfo,
-                          already_AddRefed<nsIJARChannel>&& aJarChannel,
-                          nsIFile* aJarFile)
-      : mURI(aURI)
-      , mLoadInfo(aLoadInfo)
-      , mJarChannel(Move(aJarChannel))
-      , mJarFile(aJarFile)
-      , mIsJarChannel(true)
-    {
-      MOZ_ASSERT(aURI);
-      MOZ_ASSERT(aLoadInfo);
-      MOZ_ASSERT(mJarChannel);
-      MOZ_ASSERT(aJarFile);
+  // Get an input stream or file descriptor from the parent asynchronously.
+  Result<Ok, nsresult> GetAsync(nsIStreamListener* aListener,
+                                nsIChannel* aChannel);
 
-      SetupEventTarget();
-    }
+  // Handle an input stream being returned from the parent
+  void OnStream(already_AddRefed<nsIInputStream> aStream);
 
-    ~ExtensionStreamGetter() {}
+  // Handle file descriptor being returned from the parent
+  void OnFD(const FileDescriptor& aFD);
 
-    void SetupEventTarget()
-    {
-      mMainThreadEventTarget =
-        nsContentUtils::GetEventTargetByLoadInfo(mLoadInfo, TaskCategory::Other);
-      if (!mMainThreadEventTarget) {
-        mMainThreadEventTarget = GetMainThreadSerialEventTarget();
-      }
-    }
+  MOZ_DECLARE_REFCOUNTED_TYPENAME(ExtensionStreamGetter)
 
-    // Get an input stream or file descriptor from the parent asynchronously.
-    Result<Ok, nsresult> GetAsync(nsIStreamListener* aListener,
-                                  nsIChannel* aChannel);
-
-    // Handle an input stream being returned from the parent
-    void OnStream(already_AddRefed<nsIInputStream> aStream);
-
-    // Handle file descriptor being returned from the parent
-    void OnFD(const FileDescriptor& aFD);
-
-    MOZ_DECLARE_REFCOUNTED_TYPENAME(ExtensionStreamGetter)
-
-  private:
-    nsCOMPtr<nsIURI> mURI;
-    nsCOMPtr<nsILoadInfo> mLoadInfo;
-    nsCOMPtr<nsIJARChannel> mJarChannel;
-    nsCOMPtr<nsIFile> mJarFile;
-    nsCOMPtr<nsIStreamListener> mListener;
-    nsCOMPtr<nsIChannel> mChannel;
-    nsCOMPtr<nsISerialEventTarget> mMainThreadEventTarget;
-    bool mIsJarChannel;
+ private:
+  nsCOMPtr<nsIURI> mURI;
+  nsCOMPtr<nsILoadInfo> mLoadInfo;
+  nsCOMPtr<nsIJARChannel> mJarChannel;
+  nsCOMPtr<nsIFile> mJarFile;
+  nsCOMPtr<nsIStreamListener> mListener;
+  nsCOMPtr<nsIChannel> mChannel;
+  nsCOMPtr<nsISerialEventTarget> mMainThreadEventTarget;
+  bool mIsJarChannel;
 };
 
-class ExtensionJARFileOpener : public nsISupports
-{
-public:
+class ExtensionJARFileOpener : public nsISupports {
+ public:
   ExtensionJARFileOpener(nsIFile* aFile,
-                         NeckoParent::GetExtensionFDResolver& aResolve) :
-    mFile(aFile),
-    mResolve(aResolve)
-  {
+                         NeckoParent::GetExtensionFDResolver& aResolve)
+      : mFile(aFile), mResolve(aResolve) {
     MOZ_ASSERT(aFile);
     MOZ_ASSERT(aResolve);
   }
 
-  NS_IMETHOD OpenFile()
-  {
+  NS_IMETHOD OpenFile() {
     MOZ_ASSERT(!NS_IsMainThread());
     AutoFDClose prFileDesc;
 
@@ -168,20 +158,19 @@ public:
 
     if (NS_SUCCEEDED(rv)) {
       mFD = FileDescriptor(FileDescriptor::PlatformHandleType(
-                           PR_FileDesc2NativeHandle(prFileDesc)));
+          PR_FileDesc2NativeHandle(prFileDesc)));
     }
 
     nsCOMPtr<nsIRunnable> event =
-      mozilla::NewRunnableMethod("ExtensionJarFileFDResolver",
-        this, &ExtensionJARFileOpener::SendBackFD);
+        mozilla::NewRunnableMethod("ExtensionJarFileFDResolver", this,
+                                   &ExtensionJARFileOpener::SendBackFD);
 
     rv = NS_DispatchToMainThread(event, nsIEventTarget::DISPATCH_NORMAL);
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "NS_DispatchToMainThread");
     return NS_OK;
   }
 
-  NS_IMETHOD SendBackFD()
-  {
+  NS_IMETHOD SendBackFD() {
     MOZ_ASSERT(NS_IsMainThread());
     mResolve(mFD);
     mResolve = nullptr;
@@ -190,7 +179,7 @@ public:
 
   NS_DECL_THREADSAFE_ISUPPORTS
 
-private:
+ private:
   virtual ~ExtensionJARFileOpener() {}
 
   nsCOMPtr<nsIFile> mFile;
@@ -206,10 +195,8 @@ NS_IMPL_ISUPPORTS(ExtensionJARFileOpener, nsISupports)
 #define DEFAULT_THREAD_TIMEOUT_MS 30000
 
 // Request an FD or input stream from the parent.
-Result<Ok, nsresult>
-ExtensionStreamGetter::GetAsync(nsIStreamListener* aListener,
-                                nsIChannel* aChannel)
-{
+Result<Ok, nsresult> ExtensionStreamGetter::GetAsync(
+    nsIStreamListener* aListener, nsIChannel* aChannel) {
   MOZ_ASSERT(IsNeckoChild());
   MOZ_ASSERT(mMainThreadEventTarget);
 
@@ -224,37 +211,28 @@ ExtensionStreamGetter::GetAsync(nsIStreamListener* aListener,
   if (mIsJarChannel) {
     // Request an FD for this moz-extension URI
     gNeckoChild->SendGetExtensionFD(uri)->Then(
-      mMainThreadEventTarget,
-      __func__,
-      [self] (const FileDescriptor& fd) {
-        self->OnFD(fd);
-      },
-      [self] (const mozilla::ipc::ResponseRejectReason) {
-        self->OnFD(FileDescriptor());
-      }
-    );
+        mMainThreadEventTarget, __func__,
+        [self](const FileDescriptor& fd) { self->OnFD(fd); },
+        [self](const mozilla::ipc::ResponseRejectReason) {
+          self->OnFD(FileDescriptor());
+        });
     return Ok();
   }
 
   // Request an input stream for this moz-extension URI
   gNeckoChild->SendGetExtensionStream(uri)->Then(
-    mMainThreadEventTarget,
-    __func__,
-    [self] (const nsCOMPtr<nsIInputStream>& stream) {
-      self->OnStream(do_AddRef(stream));
-    },
-    [self] (const mozilla::ipc::ResponseRejectReason) {
-      self->OnStream(nullptr);
-    }
-  );
+      mMainThreadEventTarget, __func__,
+      [self](const nsCOMPtr<nsIInputStream>& stream) {
+        self->OnStream(do_AddRef(stream));
+      },
+      [self](const mozilla::ipc::ResponseRejectReason) {
+        self->OnStream(nullptr);
+      });
   return Ok();
 }
 
-static void
-CancelRequest(nsIStreamListener* aListener,
-              nsIChannel* aChannel,
-              nsresult aResult)
-{
+static void CancelRequest(nsIStreamListener* aListener, nsIChannel* aChannel,
+                          nsresult aResult) {
   MOZ_ASSERT(aListener);
   MOZ_ASSERT(aChannel);
 
@@ -264,9 +242,7 @@ CancelRequest(nsIStreamListener* aListener,
 }
 
 // Handle an input stream sent from the parent.
-void
-ExtensionStreamGetter::OnStream(already_AddRefed<nsIInputStream> aStream)
-{
+void ExtensionStreamGetter::OnStream(already_AddRefed<nsIInputStream> aStream) {
   MOZ_ASSERT(IsNeckoChild());
   MOZ_ASSERT(mListener);
   MOZ_ASSERT(mMainThreadEventTarget);
@@ -286,8 +262,8 @@ ExtensionStreamGetter::OnStream(already_AddRefed<nsIInputStream> aStream)
   }
 
   nsCOMPtr<nsIInputStreamPump> pump;
-  nsresult rv = NS_NewInputStreamPump(getter_AddRefs(pump), stream.forget(),
-                                      0, 0, false, mMainThreadEventTarget);
+  nsresult rv = NS_NewInputStreamPump(getter_AddRefs(pump), stream.forget(), 0,
+                                      0, false, mMainThreadEventTarget);
   if (NS_FAILED(rv)) {
     CancelRequest(listener, mChannel, rv);
     return;
@@ -300,9 +276,7 @@ ExtensionStreamGetter::OnStream(already_AddRefed<nsIInputStream> aStream)
 }
 
 // Handle an FD sent from the parent.
-void
-ExtensionStreamGetter::OnFD(const FileDescriptor& aFD)
-{
+void ExtensionStreamGetter::OnFD(const FileDescriptor& aFD) {
   MOZ_ASSERT(IsNeckoChild());
   MOZ_ASSERT(mListener);
   MOZ_ASSERT(mChannel);
@@ -324,15 +298,15 @@ ExtensionStreamGetter::OnFD(const FileDescriptor& aFD)
   }
 }
 
-NS_IMPL_QUERY_INTERFACE(ExtensionProtocolHandler, nsISubstitutingProtocolHandler,
-                        nsIProtocolHandler, nsIProtocolHandlerWithDynamicFlags,
+NS_IMPL_QUERY_INTERFACE(ExtensionProtocolHandler,
+                        nsISubstitutingProtocolHandler, nsIProtocolHandler,
+                        nsIProtocolHandlerWithDynamicFlags,
                         nsISupportsWeakReference)
 NS_IMPL_ADDREF_INHERITED(ExtensionProtocolHandler, SubstitutingProtocolHandler)
 NS_IMPL_RELEASE_INHERITED(ExtensionProtocolHandler, SubstitutingProtocolHandler)
 
 already_AddRefed<ExtensionProtocolHandler>
-ExtensionProtocolHandler::GetSingleton()
-{
+ExtensionProtocolHandler::GetSingleton() {
   if (!sSingleton) {
     sSingleton = new ExtensionProtocolHandler();
     ClearOnShutdown(&sSingleton);
@@ -341,12 +315,14 @@ ExtensionProtocolHandler::GetSingleton()
 }
 
 ExtensionProtocolHandler::ExtensionProtocolHandler()
-  : SubstitutingProtocolHandler(EXTENSION_SCHEME)
+    : SubstitutingProtocolHandler(EXTENSION_SCHEME)
 #if !defined(XP_WIN)
 #if defined(XP_MACOSX)
-  , mAlreadyCheckedDevRepo(false)
+      ,
+      mAlreadyCheckedDevRepo(false)
 #endif /* XP_MACOSX */
-  , mAlreadyCheckedAppDir(false)
+      ,
+      mAlreadyCheckedAppDir(false)
 #endif /* ! XP_WIN */
 {
   // Note, extensions.webextensions.protocol.remote=false is for
@@ -354,21 +330,20 @@ ExtensionProtocolHandler::ExtensionProtocolHandler()
   // processes (specifically content and extension processes), will
   // not be able to load most moz-extension URI's when the pref is
   // set to false.
-  mUseRemoteFileChannels = IsNeckoChild() &&
-    Preferences::GetBool("extensions.webextensions.protocol.remote");
+  mUseRemoteFileChannels =
+      IsNeckoChild() &&
+      Preferences::GetBool("extensions.webextensions.protocol.remote");
 }
 
-static inline ExtensionPolicyService&
-EPS()
-{
+static inline ExtensionPolicyService& EPS() {
   return ExtensionPolicyService::GetSingleton();
 }
 
-nsresult
-ExtensionProtocolHandler::GetFlagsForURI(nsIURI* aURI, uint32_t* aFlags)
-{
-  // In general a moz-extension URI is only loadable by chrome, but a whitelisted
-  // subset are web-accessible (and cross-origin fetchable). Check that whitelist.
+nsresult ExtensionProtocolHandler::GetFlagsForURI(nsIURI* aURI,
+                                                  uint32_t* aFlags) {
+  // In general a moz-extension URI is only loadable by chrome, but a
+  // whitelisted subset are web-accessible (and cross-origin fetchable). Check
+  // that whitelist.
   bool loadableByAnyone = false;
 
   URLInfo url(aURI);
@@ -376,16 +351,17 @@ ExtensionProtocolHandler::GetFlagsForURI(nsIURI* aURI, uint32_t* aFlags)
     loadableByAnyone = policy->IsPathWebAccessible(url.FilePath());
   }
 
-  *aFlags = URI_STD | URI_IS_LOCAL_RESOURCE | (loadableByAnyone ? (URI_LOADABLE_BY_ANYONE | URI_FETCHABLE_BY_ANYONE) : URI_DANGEROUS_TO_LOAD);
+  *aFlags =
+      URI_STD | URI_IS_LOCAL_RESOURCE |
+      (loadableByAnyone ? (URI_LOADABLE_BY_ANYONE | URI_FETCHABLE_BY_ANYONE)
+                        : URI_DANGEROUS_TO_LOAD);
   return NS_OK;
 }
 
-bool
-ExtensionProtocolHandler::ResolveSpecialCases(const nsACString& aHost,
-                                              const nsACString& aPath,
-                                              const nsACString& aPathname,
-                                              nsACString& aResult)
-{
+bool ExtensionProtocolHandler::ResolveSpecialCases(const nsACString& aHost,
+                                                   const nsACString& aPath,
+                                                   const nsACString& aPathname,
+                                                   nsACString& aResult) {
   // Create special moz-extension:-pages such as moz-extension://foo/_blank.html
   // for all registered extensions. We can't just do this as a substitution
   // because substitutions can only match on host.
@@ -402,11 +378,8 @@ ExtensionProtocolHandler::ResolveSpecialCases(const nsACString& aHost,
 }
 
 // For file or JAR URI's, substitute in a remote channel.
-Result<Ok, nsresult>
-ExtensionProtocolHandler::SubstituteRemoteChannel(nsIURI* aURI,
-                                                  nsILoadInfo* aLoadInfo,
-                                                  nsIChannel** aRetVal)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::SubstituteRemoteChannel(
+    nsIURI* aURI, nsILoadInfo* aLoadInfo, nsIChannel** aRetVal) {
   MOZ_ASSERT(IsNeckoChild());
   MOZ_TRY(aURI ? NS_OK : NS_ERROR_INVALID_ARG);
   MOZ_TRY(aLoadInfo ? NS_OK : NS_ERROR_INVALID_ARG);
@@ -440,11 +413,9 @@ ExtensionProtocolHandler::SubstituteRemoteChannel(nsIURI* aURI,
   return Ok();
 }
 
-nsresult
-ExtensionProtocolHandler::SubstituteChannel(nsIURI* aURI,
-                                            nsILoadInfo* aLoadInfo,
-                                            nsIChannel** result)
-{
+nsresult ExtensionProtocolHandler::SubstituteChannel(nsIURI* aURI,
+                                                     nsILoadInfo* aLoadInfo,
+                                                     nsIChannel** result) {
   nsresult rv;
   nsCOMPtr<nsIURL> url = do_QueryInterface(aURI, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
@@ -465,30 +436,31 @@ ExtensionProtocolHandler::SubstituteChannel(nsIURI* aURI,
 
   bool haveLoadInfo = aLoadInfo;
   nsCOMPtr<nsIChannel> channel = NS_NewSimpleChannel(
-    aURI, aLoadInfo, *result,
-    [haveLoadInfo] (nsIStreamListener* listener, nsIChannel* channel, nsIChannel* origChannel) -> RequestOrReason {
-      nsresult rv;
-      nsCOMPtr<nsIStreamConverterService> convService =
-        do_GetService(NS_STREAMCONVERTERSERVICE_CONTRACTID, &rv);
-      MOZ_TRY(rv);
+      aURI, aLoadInfo, *result,
+      [haveLoadInfo](nsIStreamListener* listener, nsIChannel* channel,
+                     nsIChannel* origChannel) -> RequestOrReason {
+        nsresult rv;
+        nsCOMPtr<nsIStreamConverterService> convService =
+            do_GetService(NS_STREAMCONVERTERSERVICE_CONTRACTID, &rv);
+        MOZ_TRY(rv);
 
-      nsCOMPtr<nsIURI> uri;
-      MOZ_TRY(channel->GetURI(getter_AddRefs(uri)));
+        nsCOMPtr<nsIURI> uri;
+        MOZ_TRY(channel->GetURI(getter_AddRefs(uri)));
 
-      const char* kFromType = "application/vnd.mozilla.webext.unlocalized";
-      const char* kToType = "text/css";
+        const char* kFromType = "application/vnd.mozilla.webext.unlocalized";
+        const char* kToType = "text/css";
 
-      nsCOMPtr<nsIStreamListener> converter;
-      MOZ_TRY(convService->AsyncConvertData(kFromType, kToType, listener,
-                                        uri, getter_AddRefs(converter)));
-      if (haveLoadInfo) {
-        MOZ_TRY(origChannel->AsyncOpen2(converter));
-      } else {
-        MOZ_TRY(origChannel->AsyncOpen(converter, nullptr));
-      }
+        nsCOMPtr<nsIStreamListener> converter;
+        MOZ_TRY(convService->AsyncConvertData(kFromType, kToType, listener, uri,
+                                              getter_AddRefs(converter)));
+        if (haveLoadInfo) {
+          MOZ_TRY(origChannel->AsyncOpen2(converter));
+        } else {
+          MOZ_TRY(origChannel->AsyncOpen(converter, nullptr));
+        }
 
-      return RequestOrReason(origChannel);
-    });
+        return RequestOrReason(origChannel);
+      });
   NS_ENSURE_TRUE(channel, NS_ERROR_OUT_OF_MEMORY);
 
   if (aLoadInfo) {
@@ -502,11 +474,8 @@ ExtensionProtocolHandler::SubstituteChannel(nsIURI* aURI,
   return NS_OK;
 }
 
-Result<Ok, nsresult>
-ExtensionProtocolHandler::AllowExternalResource(nsIFile* aExtensionDir,
-                                                nsIFile* aRequestedFile,
-                                                bool* aResult)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::AllowExternalResource(
+    nsIFile* aExtensionDir, nsIFile* aRequestedFile, bool* aResult) {
   MOZ_ASSERT(!IsNeckoChild());
   MOZ_ASSERT(aResult);
   *aResult = false;
@@ -543,10 +512,8 @@ ExtensionProtocolHandler::AllowExternalResource(nsIFile* aExtensionDir,
 
 #if defined(XP_MACOSX)
 // The |aRequestedFile| argument must already be Normalize()'d
-Result<Ok, nsresult>
-ExtensionProtocolHandler::DevRepoContains(nsIFile* aRequestedFile,
-                                          bool* aResult)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::DevRepoContains(
+    nsIFile* aRequestedFile, bool* aResult) {
   MOZ_ASSERT(mozilla::IsDevelopmentBuild());
   MOZ_ASSERT(!IsNeckoChild());
   MOZ_ASSERT(aResult);
@@ -572,10 +539,8 @@ ExtensionProtocolHandler::DevRepoContains(nsIFile* aRequestedFile,
 #endif /* XP_MACOSX */
 
 #if !defined(XP_WIN)
-Result<Ok, nsresult>
-ExtensionProtocolHandler::AppDirContains(nsIFile* aExtensionDir,
-                                         bool* aResult)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::AppDirContains(
+    nsIFile* aExtensionDir, bool* aResult) {
   MOZ_ASSERT(mozilla::IsDevelopmentBuild());
   MOZ_ASSERT(!IsNeckoChild());
   MOZ_ASSERT(aResult);
@@ -600,20 +565,19 @@ ExtensionProtocolHandler::AppDirContains(nsIFile* aExtensionDir,
 }
 #endif /* !defined(XP_WIN) */
 
-static void
-LogExternalResourceError(nsIFile* aExtensionDir, nsIFile* aRequestedFile)
-{
+static void LogExternalResourceError(nsIFile* aExtensionDir,
+                                     nsIFile* aRequestedFile) {
   MOZ_ASSERT(aExtensionDir);
   MOZ_ASSERT(aRequestedFile);
 
   LOG("Rejecting external unpacked extension resource [%s] from "
-      "extension directory [%s]", aRequestedFile->HumanReadablePath().get(),
+      "extension directory [%s]",
+      aRequestedFile->HumanReadablePath().get(),
       aExtensionDir->HumanReadablePath().get());
 }
 
-Result<nsCOMPtr<nsIInputStream>, nsresult>
-ExtensionProtocolHandler::NewStream(nsIURI* aChildURI, bool* aTerminateSender)
-{
+Result<nsCOMPtr<nsIInputStream>, nsresult> ExtensionProtocolHandler::NewStream(
+    nsIURI* aChildURI, bool* aTerminateSender) {
   MOZ_ASSERT(!IsNeckoChild());
   MOZ_TRY(aChildURI ? NS_OK : NS_ERROR_INVALID_ARG);
   MOZ_TRY(aTerminateSender ? NS_OK : NS_ERROR_INVALID_ARG);
@@ -680,17 +644,14 @@ ExtensionProtocolHandler::NewStream(nsIURI* aChildURI, bool* aTerminateSender)
   MOZ_TRY(rv);
 
   nsCOMPtr<nsIURI> resolvedURI;
-  MOZ_TRY(ioService->NewURI(resolvedSpec,
-                            nullptr,
-                            nullptr,
+  MOZ_TRY(ioService->NewURI(resolvedSpec, nullptr, nullptr,
                             getter_AddRefs(resolvedURI)));
 
   // We use the system principal to get a file channel for the request,
   // but only after we've checked (above) that the child URI is of
   // moz-extension scheme and that the URI host maps to a directory.
   nsCOMPtr<nsIChannel> channel;
-  MOZ_TRY(NS_NewChannel(getter_AddRefs(channel),
-                        resolvedURI,
+  MOZ_TRY(NS_NewChannel(getter_AddRefs(channel), resolvedURI,
                         nsContentUtils::GetSystemPrincipal(),
                         nsILoadInfo::SEC_ALLOW_CROSS_ORIGIN_DATA_IS_NULL,
                         nsIContentPolicy::TYPE_OTHER));
@@ -728,20 +689,16 @@ ExtensionProtocolHandler::NewStream(nsIURI* aChildURI, bool* aTerminateSender)
   }
 
   nsCOMPtr<nsIInputStream> inputStream;
-  MOZ_TRY(NS_NewLocalFileInputStream(getter_AddRefs(inputStream),
-                                     requestedFile,
-                                     PR_RDONLY,
-                                     -1,
+  MOZ_TRY(NS_NewLocalFileInputStream(getter_AddRefs(inputStream), requestedFile,
+                                     PR_RDONLY, -1,
                                      nsIFileInputStream::DEFER_OPEN));
 
   return inputStream;
 }
 
-Result<Ok, nsresult>
-ExtensionProtocolHandler::NewFD(nsIURI* aChildURI,
-                                bool* aTerminateSender,
-                                NeckoParent::GetExtensionFDResolver& aResolve)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::NewFD(
+    nsIURI* aChildURI, bool* aTerminateSender,
+    NeckoParent::GetExtensionFDResolver& aResolve) {
   MOZ_ASSERT(!IsNeckoChild());
   MOZ_TRY(aChildURI ? NS_OK : NS_ERROR_INVALID_ARG);
   MOZ_TRY(aTerminateSender ? NS_OK : NS_ERROR_INVALID_ARG);
@@ -782,16 +739,15 @@ ExtensionProtocolHandler::NewFD(nsIURI* aChildURI,
 
   if (!mFileOpenerThread) {
     mFileOpenerThread =
-      new LazyIdleThread(DEFAULT_THREAD_TIMEOUT_MS,
-                         NS_LITERAL_CSTRING("ExtensionProtocolHandler"));
+        new LazyIdleThread(DEFAULT_THREAD_TIMEOUT_MS,
+                           NS_LITERAL_CSTRING("ExtensionProtocolHandler"));
   }
 
   RefPtr<ExtensionJARFileOpener> fileOpener =
-    new ExtensionJARFileOpener(jarFile, aResolve);
+      new ExtensionJARFileOpener(jarFile, aResolve);
 
-  nsCOMPtr<nsIRunnable> event =
-    mozilla::NewRunnableMethod("ExtensionJarFileOpener",
-        fileOpener, &ExtensionJARFileOpener::OpenFile);
+  nsCOMPtr<nsIRunnable> event = mozilla::NewRunnableMethod(
+      "ExtensionJarFileOpener", fileOpener, &ExtensionJARFileOpener::OpenFile);
 
   MOZ_TRY(mFileOpenerThread->Dispatch(event, nsIEventTarget::DISPATCH_NORMAL));
 
@@ -799,9 +755,7 @@ ExtensionProtocolHandler::NewFD(nsIURI* aChildURI,
 }
 
 // Set the channel's content type using the provided URI's type
-void
-SetContentType(nsIURI* aURI, nsIChannel* aChannel)
-{
+void SetContentType(nsIURI* aURI, nsIChannel* aChannel) {
   nsresult rv;
   nsCOMPtr<nsIMIMEService> mime = do_GetService("@mozilla.org/mime;1", &rv);
   if (NS_SUCCEEDED(rv)) {
@@ -814,65 +768,53 @@ SetContentType(nsIURI* aURI, nsIChannel* aChannel)
 }
 
 // Gets a SimpleChannel that wraps the provided ExtensionStreamGetter
-static void
-NewSimpleChannel(nsIURI* aURI,
-                 nsILoadInfo* aLoadinfo,
-                 ExtensionStreamGetter* aStreamGetter,
-                 nsIChannel** aRetVal)
-{
+static void NewSimpleChannel(nsIURI* aURI, nsILoadInfo* aLoadinfo,
+                             ExtensionStreamGetter* aStreamGetter,
+                             nsIChannel** aRetVal) {
   nsCOMPtr<nsIChannel> channel = NS_NewSimpleChannel(
-    aURI, aLoadinfo, aStreamGetter,
-    [] (nsIStreamListener* listener, nsIChannel* simpleChannel,
-        ExtensionStreamGetter* getter) -> RequestOrReason {
-      MOZ_TRY(getter->GetAsync(listener, simpleChannel));
-      return RequestOrReason(nullptr);
-    });
+      aURI, aLoadinfo, aStreamGetter,
+      [](nsIStreamListener* listener, nsIChannel* simpleChannel,
+         ExtensionStreamGetter* getter) -> RequestOrReason {
+        MOZ_TRY(getter->GetAsync(listener, simpleChannel));
+        return RequestOrReason(nullptr);
+      });
 
   SetContentType(aURI, channel);
   channel.swap(*aRetVal);
 }
 
 // Gets a SimpleChannel that wraps the provided channel
-static void
-NewSimpleChannel(nsIURI* aURI,
-                 nsILoadInfo* aLoadinfo,
-                 nsIChannel* aChannel,
-                 nsIChannel** aRetVal)
-{
-  nsCOMPtr<nsIChannel> channel = NS_NewSimpleChannel(aURI, aLoadinfo, aChannel,
-    [] (nsIStreamListener* listener, nsIChannel* simpleChannel,
-        nsIChannel* origChannel) -> RequestOrReason {
-      nsresult rv = origChannel->AsyncOpen2(listener);
-      if (NS_FAILED(rv)) {
-        simpleChannel->Cancel(NS_BINDING_ABORTED);
-        return RequestOrReason(rv);
-      }
-      return RequestOrReason(origChannel);
-    });
+static void NewSimpleChannel(nsIURI* aURI, nsILoadInfo* aLoadinfo,
+                             nsIChannel* aChannel, nsIChannel** aRetVal) {
+  nsCOMPtr<nsIChannel> channel = NS_NewSimpleChannel(
+      aURI, aLoadinfo, aChannel,
+      [](nsIStreamListener* listener, nsIChannel* simpleChannel,
+         nsIChannel* origChannel) -> RequestOrReason {
+        nsresult rv = origChannel->AsyncOpen2(listener);
+        if (NS_FAILED(rv)) {
+          simpleChannel->Cancel(NS_BINDING_ABORTED);
+          return RequestOrReason(rv);
+        }
+        return RequestOrReason(origChannel);
+      });
 
   SetContentType(aURI, channel);
   channel.swap(*aRetVal);
 }
 
-void
-ExtensionProtocolHandler::SubstituteRemoteFileChannel(nsIURI* aURI,
-                                                      nsILoadInfo* aLoadinfo,
-                                                      nsACString& aResolvedFileSpec,
-                                                      nsIChannel** aRetVal)
-{
+void ExtensionProtocolHandler::SubstituteRemoteFileChannel(
+    nsIURI* aURI, nsILoadInfo* aLoadinfo, nsACString& aResolvedFileSpec,
+    nsIChannel** aRetVal) {
   MOZ_ASSERT(IsNeckoChild());
 
   RefPtr<ExtensionStreamGetter> streamGetter =
-    new ExtensionStreamGetter(aURI, aLoadinfo);
+      new ExtensionStreamGetter(aURI, aLoadinfo);
 
   NewSimpleChannel(aURI, aLoadinfo, streamGetter, aRetVal);
 }
 
-static Result<Ok, nsresult>
-LogCacheCheck(const nsIJARChannel* aJarChannel,
-              nsIJARURI* aJarURI,
-              bool aIsCached)
-{
+static Result<Ok, nsresult> LogCacheCheck(const nsIJARChannel* aJarChannel,
+                                          nsIJARURI* aJarURI, bool aIsCached) {
   nsresult rv;
 
   nsCOMPtr<nsIURI> innerFileURI;
@@ -887,18 +829,15 @@ LogCacheCheck(const nsIJARChannel* aJarChannel,
   nsAutoCString uriSpec, jarSpec;
   Unused << aJarURI->GetSpec(uriSpec);
   Unused << innerFileURI->GetSpec(jarSpec);
-  LOG("[JARChannel %p] Cache %s: %s (%s)",
-      aJarChannel, aIsCached ? "hit" : "miss", uriSpec.get(), jarSpec.get());
+  LOG("[JARChannel %p] Cache %s: %s (%s)", aJarChannel,
+      aIsCached ? "hit" : "miss", uriSpec.get(), jarSpec.get());
 
   return Ok();
 }
 
-Result<Ok, nsresult>
-ExtensionProtocolHandler::SubstituteRemoteJarChannel(nsIURI* aURI,
-                                                     nsILoadInfo* aLoadinfo,
-                                                     nsACString& aResolvedSpec,
-                                                     nsIChannel** aRetVal)
-{
+Result<Ok, nsresult> ExtensionProtocolHandler::SubstituteRemoteJarChannel(
+    nsIURI* aURI, nsILoadInfo* aLoadinfo, nsACString& aResolvedSpec,
+    nsIChannel** aRetVal) {
   MOZ_ASSERT(IsNeckoChild());
   nsresult rv;
 
@@ -940,14 +879,11 @@ ExtensionProtocolHandler::SubstituteRemoteJarChannel(nsIURI* aURI,
   MOZ_TRY(innerFileURL->GetFile(getter_AddRefs(jarFile)));
 
   RefPtr<ExtensionStreamGetter> streamGetter =
-    new ExtensionStreamGetter(aURI,
-                              aLoadinfo,
-                              jarChannel.forget(),
-                              jarFile);
+      new ExtensionStreamGetter(aURI, aLoadinfo, jarChannel.forget(), jarFile);
 
   NewSimpleChannel(aURI, aLoadinfo, streamGetter, aRetVal);
   return Ok();
 }
 
-} // namespace net
-} // namespace mozilla
+}  // namespace net
+}  // namespace mozilla
